@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013 The SCons Foundation
+# Copyright (c) 2001 - 2014 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -27,7 +27,7 @@ This file implements the warnings framework for SCons.
 
 """
 
-__revision__ = "src/engine/SCons/Warnings.py  2013/03/03 09:48:35 garyo"
+__revision__ = "src/engine/SCons/Warnings.py  2014/08/24 12:12:31 garyo"
 
 import sys
 
@@ -42,6 +42,9 @@ class WarningOnByDefault(Warning):
 
 # NOTE:  If you add a new warning class, add it to the man page, too!
 
+class TargetNotBuiltWarning(Warning): # Should go to OnByDefault
+    pass
+
 class CacheWriteErrorWarning(Warning):
     pass
 
@@ -51,6 +54,9 @@ class CorruptSConsignWarning(WarningOnByDefault):
 class DependencyWarning(Warning):
     pass
 
+class DevelopmentVersionWarning(WarningOnByDefault):
+    pass
+
 class DuplicateEnvironmentWarning(WarningOnByDefault):
     pass
 
